package com.ruoyi.post.frequency.posshield.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.post.frequency.posshield.entity.PostShield;
import com.ruoyi.vo.UserVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 论坛屏蔽Mapper接口
 * 
 * @author liwenlong
 * @date 2023-10-26
 */
public interface PostShieldMapper  extends BaseMapper<PostShield>
{
    /**
     * 查询论坛屏蔽
     * 
     * @param id 论坛屏蔽主键
     * @return 论坛屏蔽
     */
    public PostShield selectPostShieldById(Long id);

    /**
     * 查询论坛屏蔽列表
     * 
     * @param postShield 论坛屏蔽
     * @return 论坛屏蔽集合
     */
    public List<PostShield> selectPostShieldList(PostShield postShield);

    /**
     * 新增论坛屏蔽
     * 
     * @param postShield 论坛屏蔽
     * @return 结果
     */
    public int insertPostShield(PostShield postShield);

    /**
     * 修改论坛屏蔽
     * 
     * @param postShield 论坛屏蔽
     * @return 结果
     */
    public int updatePostShield(PostShield postShield);

    /**
     * 删除论坛屏蔽
     * 
     * @param id 论坛屏蔽主键
     * @return 结果
     */
    public int deletePostShieldById(Long id);

    /**
     * 批量删除论坛屏蔽
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePostShieldByIds(Long[] ids);

    /**
     * 帖子屏蔽
     * @param postShield
     * @param userVo
     */
    int postShield(@Param("req") PostShield postShield,@Param("userVo") UserVo userVo);
}
